proposals: agenda: [ ] gender ( ) male ( ) female ( ) other species: for people: for dogs: for rabbits: thresholds: estimated intake interval: thresholds common: EAR, estimated average requirement lower than this is a bad idea. RDA, recommended dietary allowance at this point, you should have close to 0% risk of having inadequate amount. AI, adequate intake UL, tolerable upper intake level beyond this point, the risk of adverse effects from taking too much are possible. these could merge with shapes: given shape: { "names": [ "vitamin a" ] "unites": [ "retinol", "retinal", "retinoic acid" ], "unites probable eventualities": [ ] } becomes: { "names": [ "vitamin a" ] "unites": [ "retinol", "retinal", "retinoic acid" ], "unites probable eventualities": [ ] }